==> simple-scan-0.7.3.tar.gz: simple-scan-0.7.3/src/ui.h <==
/*
 * Copyright (C) 2009 Canonical Ltd.
 * Author: Robert Ancell <robert.ancell@canonical.com>
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
 * license.
 */

#ifndef _UI_H_
#define _UI_H_

#include <glib-object.h>
#include "book.h"

G_BEGIN_DECLS

#define SIMPLE_SCAN_TYPE  (ui_get_type ())
#define SIMPLE_SCAN(obj)  (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIMPLE_SCAN_TYPE, SimpleScan))


typedef struct SimpleScanPrivate SimpleScanPrivate;

typedef struct
{
    GObject             parent_instance;
    SimpleScanPrivate  *priv;
} SimpleScan;

typedef struct
{
    GObjectClass parent_class;

    void (*start_scan) (SimpleScan *ui, const gchar *device, const gchar *document_type, gboolean continuous, gboolean replace);
    void (*stop_scan) (SimpleScan *ui);
    void (*save) (SimpleScan *ui, const gchar *format);
    void (*email) (SimpleScan *ui);
    void (*quit) (SimpleScan *ui);
} SimpleScanClass;


GType ui_get_type (void);

SimpleScan *ui_new (void);

void ui_set_book (SimpleScan *ui, Book *book);

void ui_set_selected_page (SimpleScan *ui, Page *page);

Page *ui_get_selected_page (SimpleScan *ui);

void ui_set_default_file_name (SimpleScan *ui, const gchar *default_file_name);

void ui_authorize (SimpleScan *ui, const gchar *resource, gchar **username, gchar **password);

void ui_mark_devices_undetected (SimpleScan *ui);

void ui_add_scan_device (SimpleScan *ui, const gchar *device, const gchar *label);

gchar *ui_get_selected_device (SimpleScan *ui);

void ui_set_selected_device (SimpleScan *ui, const gchar *device);

void ui_set_scanning (SimpleScan *ui, gboolean scanning);

void ui_set_have_scan (SimpleScan *ui, gboolean have_scan);

void ui_show_error (SimpleScan *ui, const gchar *error_title, const gchar *error_text);

void ui_start (SimpleScan *ui);

#endif /* _UI_H_ */

==> simple-scan-0.9.0.tar.gz: simple-scan-0.9.0/src/ui.h <==
/*
 * Copyright (C) 2009 Canonical Ltd.
 * Author: Robert Ancell <robert.ancell@canonical.com>
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
 * license.
 */

#ifndef _UI_H_
#define _UI_H_

#include <glib-object.h>
#include "book.h"
#include "scanner.h"

G_BEGIN_DECLS

#define SIMPLE_SCAN_TYPE  (ui_get_type ())
#define SIMPLE_SCAN(obj)  (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIMPLE_SCAN_TYPE, SimpleScan))


typedef struct SimpleScanPrivate SimpleScanPrivate;

typedef struct
{
    GObject             parent_instance;
    SimpleScanPrivate  *priv;
} SimpleScan;

typedef struct
{
    GObjectClass parent_class;

    void (*start_scan) (SimpleScan *ui, const gchar *device, gint dpi, const gchar *document_type, gboolean continuous);
    void (*stop_scan) (SimpleScan *ui);
    void (*save) (SimpleScan *ui, const gchar *format);
    void (*email) (SimpleScan *ui);
    void (*quit) (SimpleScan *ui);
} SimpleScanClass;


GType ui_get_type (void);

SimpleScan *ui_new (void);

Book *ui_get_book (SimpleScan *ui);

void ui_set_selected_page (SimpleScan *ui, Page *page);

Page *ui_get_selected_page (SimpleScan *ui);

void ui_set_default_file_name (SimpleScan *ui, const gchar *default_file_name);

void ui_authorize (SimpleScan *ui, const gchar *resource, gchar **username, gchar **password);

void ui_set_scan_devices (SimpleScan *ui, GList *devices);

gchar *ui_get_selected_device (SimpleScan *ui);

void ui_set_selected_device (SimpleScan *ui, const gchar *device);

void ui_set_scanning (SimpleScan *ui, gboolean scanning);

void ui_set_have_scan (SimpleScan *ui, gboolean have_scan);

void ui_show_error (SimpleScan *ui, const gchar *error_title, const gchar *error_text, gboolean change_scanner_hint);

void ui_start (SimpleScan *ui);

#endif /* _UI_H_ */
